@@ -1043,16 +1043,23 @@ def oldevolveextsetup(ui):
                      _(b"make commit obsolete this revision (DEPRECATED)")))
 
 @eh.wrapfunction(obsolete, '_checkinvalidmarkers')
-def _checkinvalidmarkers(orig, markers):
+def _checkinvalidmarkers(orig, *args):
     """search for marker with invalid data and raise error if needed
 
     Exist as a separated function to allow the evolve extension for a more
     subtle handling.
     """
+    if len(args) == 2:
+        repo_nullid = args[0].nullid
+        markers = args[1]
+    else:
+        # hg <= 5.8 (d55b71393907)
+        repo_nullid = nullid
+        markers = args[0]
     if r'debugobsconvert' in sys.argv:
         return
     for mark in markers:
-        if nullid in mark[1]:
+        if repo_nullid in mark[1]:
             msg = _(b'bad obsolescence marker detected: invalid successors nullid')
             hint = _(b'You should run `hg debugobsconvert`')
             raise error.Abort(msg, hint=hint)
