@@ -340,52 +340,6 @@ def _commitfiltered(repo, ctx, match, target=None, message=None, user=None,
     newid = repo.commitctx(new)
     return newid
 
-# TODO: call core's version once we've dropped support for hg <= 4.9
-def movedirstate(repo, newctx, match=None):
-    """Move the dirstate to newctx and adjust it as necessary.
-
-    A matcher can be provided as an optimization. It is probably a bug to pass
-    a matcher that doesn't match all the differences between the parent of the
-    working copy and newctx.
-    """
-    oldctx = repo[b'.']
-    ds = repo.dirstate
-    dscopies = dict(ds.copies())
-    ds.setparents(newctx.node(), node.nullid)
-    s = newctx.status(oldctx, match=match)
-    for f in s.modified:
-        if ds[f] == b'r':
-            # modified + removed -> removed
-            continue
-        ds.normallookup(f)
-
-    for f in s.added:
-        if ds[f] == b'r':
-            # added + removed -> unknown
-            ds.drop(f)
-        elif ds[f] != b'a':
-            ds.add(f)
-
-    for f in s.removed:
-        if ds[f] == b'a':
-            # removed + added -> normal
-            ds.normallookup(f)
-        elif ds[f] != b'r':
-            ds.remove(f)
-
-    # Merge old parent and old working dir copies
-    oldcopies = copies.pathcopies(newctx, oldctx, match)
-    oldcopies.update(dscopies)
-    newcopies = {
-        dst: oldcopies.get(src, src)
-        for dst, src in oldcopies.items()
-    }
-    # Adjust the dirstate copies
-    for dst, src in newcopies.items():
-        if src not in newctx or dst in newctx or ds[dst] != b'a':
-            src = None
-        ds.copy(src, dst)
-
 @eh.command(
     b'uncommit',
     [(b'a', b'all', None, _(b'uncommit all changes when no arguments given')),
@@ -515,7 +469,7 @@ def uncommit(ui, repo, *pats, **opts):
             compat.clean_update(repo[newid])
         else:
             with repo.dirstate.parentchange(), compat.parentchange(repo):
-                movedirstate(repo, repo[newid], match)
+                compat.movedirstate(repo, repo[newid], match)
         if not repo[newid].files():
             ui.warn(_(b"new changeset is empty\n"))
             ui.status(_(b"(use 'hg prune .' to remove it)\n"))
@@ -734,11 +688,8 @@ def fold(ui, repo, *revs, **opts):
             if opts.get('note'):
                 metadata[b'note'] = opts['note']
 
-            updates = allctx[:]
-            if p2 is not None and root.p2() != p2:
-                updates.append(p2)
             commitopts = pycompat.byteskwargs(commitopts)
-            newid, unusedvariable = rewriteutil.rewrite(repo, root, updates,
+            newid, unusedvariable = rewriteutil.rewrite(repo, root,
                                                         head,
                                                         [root.p1().node(),
                                                          p2.node()],
@@ -854,13 +805,10 @@ def metaedit(ui, repo, *revs, **opts):
                 commitopts['message'] = b"\n".join(msgs)
                 commitopts['edit'] = True
 
-            updates = allctx[:]
-            if p2 is not None and (root.p2() != p2 or not opts['fold']):
-                updates.append(p2)
             if not commitopts['fold'] and not commitopts['date']:
                 commitopts['date'] = root.date()
             commitopts = pycompat.byteskwargs(commitopts)
-            newid, created = rewriteutil.rewrite(repo, root, updates, head,
+            newid, created = rewriteutil.rewrite(repo, root, head,
                                                  [root.p1().node(),
                                                   p2.node()],
                                                  commitopts=commitopts)
@@ -1364,11 +1312,8 @@ def touchnodes(ui, repo, revs, displayer, **opts):
                 if choice == b'duplicate':
                     duplicate = True
 
-        updates = []
-        if len(ctx.parents()) > 1:
-            updates = ctx.parents()
         extradict = {b'extra': extra}
-        new, unusedvariable = rewriteutil.rewrite(repo, ctx, updates, ctx,
+        new, unusedvariable = rewriteutil.rewrite(repo, ctx, ctx,
                                                   [p1, p2],
                                                   commitopts=extradict)
         # store touched version to help potential children
