@@ -11,10 +11,12 @@ import contextlib
 from mercurial import (
     cmdutil,
     context,
-    copies,
+    copies as copiesmod,
+    dirstate,
     hg,
     logcmdutil,
     merge as mergemod,
+    node,
     obsolete,
     registrar,
     repair,
@@ -94,7 +96,7 @@ try:
 except AttributeError:
     bmrevset = scmutil.bookmarkrevs
 
-hg48 = util.safehasattr(copies, 'stringutil')
+hg48 = util.safehasattr(copiesmod, 'stringutil')
 # code imported from Mercurial core at ae17555ef93f + patch
 def fixedcopytracing(repo, c1, c2, base):
     """A complete copy-patse of copies._fullcopytrace with a one line fix to
@@ -103,6 +105,7 @@ def fixedcopytracing(repo, c1, c2, base):
     gets in and once we drop support for 4.6, this should be removed."""
 
     from mercurial import pathutil
+    copies = copiesmod
 
     # In certain scenarios (e.g. graft, update or rebase), base can be
     # overridden We still need to know a real common ancestor in this case We
@@ -353,7 +356,7 @@ def fixedcopytracing(repo, c1, c2, base):
 # hg <= 4.9 (7694b685bb10)
 fixupstreamed = util.safehasattr(scmutil, 'movedirstate')
 if not fixupstreamed:
-    copies._fullcopytracing = fixedcopytracing
+    copiesmod._fullcopytracing = fixedcopytracing
 
 # help category compatibility
 # hg <= 4.7 (c303d65d2e34)
@@ -432,3 +435,97 @@ else:
     def format_changeset_summary_fn(ui, repo, command, default_spec):
         return logcmdutil.changesetdisplayer(ui, repo,
                                              {b'template': default_spec}).show
+
+if util.safehasattr(dirstate.dirstate, 'set_clean'):
+    movedirstate = scmutil.movedirstate
+else:  # hg <= 5.8 (8a50fb0784a9)
+    # TODO: call core's version once we've dropped support for hg <= 4.9
+    def movedirstate(repo, newctx, match=None):
+        """Move the dirstate to newctx and adjust it as necessary.
+
+        A matcher can be provided as an optimization. It is probably a bug to pass
+        a matcher that doesn't match all the differences between the parent of the
+        working copy and newctx.
+        """
+        oldctx = repo[b'.']
+        ds = repo.dirstate
+        dscopies = dict(ds.copies())
+        ds.setparents(newctx.node(), node.nullid)
+        s = newctx.status(oldctx, match=match)
+        for f in s.modified:
+            if ds[f] == b'r':
+                # modified + removed -> removed
+                continue
+            ds.normallookup(f)
+
+        for f in s.added:
+            if ds[f] == b'r':
+                # added + removed -> unknown
+                ds.drop(f)
+            elif ds[f] != b'a':
+                ds.add(f)
+
+        for f in s.removed:
+            if ds[f] == b'a':
+                # removed + added -> normal
+                ds.normallookup(f)
+            elif ds[f] != b'r':
+                ds.remove(f)
+
+        # Merge old parent and old working dir copies
+        oldcopies = copiesmod.pathcopies(newctx, oldctx, match)
+        oldcopies.update(dscopies)
+        newcopies = {
+            dst: oldcopies.get(src, src)
+            for dst, src in oldcopies.items()
+        }
+        # Adjust the dirstate copies
+        for dst, src in newcopies.items():
+            if src not in newctx or dst in newctx or ds[dst] != b'a':
+                src = None
+            ds.copy(src, dst)
+
+# hg <= 4.9 (e1ceefab9bca)
+code = context.overlayworkingctx._markdirty.__code__
+if 'copied' not in code.co_varnames[:code.co_argcount]:
+    def fixedmarkcopied(self, path, origin):
+        self._markdirty(path, exists=True, date=self.filedate(path),
+                        flags=self.flags(path), copied=origin)
+
+    context.overlayworkingctx.markcopied = fixedmarkcopied
+
+# what we're actually targeting here is e079e001d536
+# hg <= 5.0 (dc3fdd1b5af4)
+try:
+    from mercurial import state as statemod
+    markdirtyfixed = util.safehasattr(statemod, '_statecheck')
+except (AttributeError, ImportError):
+    markdirtyfixed = False
+if not markdirtyfixed:
+    def fixedmarkdirty(
+        self,
+        path,
+        exists,
+        data=None,
+        date=None,
+        flags='',
+        copied=None,
+    ):
+        # data not provided, let's see if we already have some; if not, let's
+        # grab it from our underlying context, so that we always have data if
+        # the file is marked as existing.
+        if exists and data is None:
+            oldentry = self._cache.get(path) or {}
+            data = oldentry.get('data')
+            if data is None:
+                data = self._wrappedctx[path].data()
+
+        self._cache[path] = {
+            'exists': exists,
+            'data': data,
+            'date': date,
+            'flags': flags,
+            'copied': copied,
+        }
+
+    context.overlayworkingctx._markdirty = fixedmarkdirty
