@@ -37,7 +37,6 @@ from mercurial.utils import stringutil
 from mercurial.i18n import _
 
 from . import (
-    cmdrewrite,
     compat,
     exthelper,
     rewriteutil,
@@ -206,7 +205,7 @@ def _solvephasedivergence(ui, repo, bumped, evolvestate, display,
         repo.ui.write(todo)
         repo.ui.write((b'hg update %s;\n' % prec))
         repo.ui.write((b'hg revert --all --rev %s;\n' % bumped))
-        repo.ui.write((b'hg commit --msg "%s update to %s"\n' %
+        repo.ui.write((b'hg commit --message "%s update to %s"\n' %
                        (TROUBLES['PHASEDIVERGENT'], bumped)))
         return (False, b".")
     if progresscb:
@@ -618,7 +617,7 @@ def _completecontentdivergent(ui, repo, progresscb, divergent, other,
         otherdiv = other if other.mutable() else divergent
 
         with repo.dirstate.parentchange(), compat.parentchange(repo):
-            cmdrewrite.movedirstate(repo, repo[publicnode])
+            compat.movedirstate(repo, repo[publicnode])
         # check if node to be committed has changes same as public one
         s = publicdiv.status()
         if not (s.added or s.removed or s.deleted or s.modified):
@@ -631,7 +630,7 @@ def _completecontentdivergent(ui, repo, progresscb, divergent, other,
             return (True, publicnode)
 
     with repo.dirstate.parentchange(), compat.parentchange(repo):
-        cmdrewrite.movedirstate(repo, repo[resparent])
+        compat.movedirstate(repo, repo[resparent])
 
     # merge the branches
     mergebranches(repo, divergent, other, base)
