@@ -86,17 +86,17 @@ server needs to have specific config for this.
 
 * everything pushed become public (the default)::
 
-    [phase]
+    [phases]
     publish = yes
 
 * nothing push turned public::
 
-    [phase]
+    [phases]
     publish = no
 
 * topic branches are not published, changeset without topic are::
 
-    [phase]
+    [phases]
     publish = no
     [experimental]
     topic.publish-bare-branch = yes
@@ -232,9 +232,9 @@ colortable = {b'topic.active': b'green',
               b'topic.active': b'green',
               }
 
-__version__ = b'0.22.2'
+__version__ = b'0.22.3'
 
-testedwith = b'4.6.2 4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8'
+testedwith = b'4.6.2 4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9'
 minimumhgversion = b'4.6'
 buglink = b'https://bz.mercurial-scm.org/'
 
